"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var base_api_1 = require("./base-api");
var storage = require("../storage");
var constants_1 = require("../constants");
var Apex = (function (_super) {
    __extends(Apex, _super);
    function Apex() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Apex.query = function (soql) {
        return this.requestData({
            path: "/services/data/" + this.apiVersion + "/query",
            params: {
                q: soql
            }
        });
    };
    Apex.retrieve = function (objectName, id, fields) {
        return this.requestData({
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/" + id,
            params: fields ? { fields: (typeof fields === 'string' ? fields : fields.join(',')) } : undefined
        });
    };
    Apex.getPickListValues = function (objectName) {
        return this.requestData({
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/describe"
        });
    };
    Apex.create = function (objectName, data) {
        return this.requestData({
            method: 'POST',
            contentType: 'application/json',
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/",
            data: data
        });
    };
    Apex.update = function (objectName, data) {
        var id = data.Id || data.id, fields = JSON.parse(JSON.stringify(data));
        delete fields.attributes;
        delete fields.Id;
        delete fields.id;
        return this.requestData({
            method: 'POST',
            contentType: 'application/json',
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/" + id,
            params: { '_HttpMethod': 'PATCH' },
            data: fields
        });
    };
    Apex.delRecord = function (objectName, id) {
        return this.requestData({
            method: 'DELETE',
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/" + id
        });
    };
    Apex.upsert = function (objectName, externalIdField, externalId, data) {
        return this.requestData({
            method: 'PATCH',
            contentType: 'application/json',
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/" + externalIdField + "/" + externalId,
            data: data
        });
    };
    Apex.restapi = function (pathOrParams) {
        var obj;
        if (typeof pathOrParams === "string") {
            obj = { path: pathOrParams, method: "GET" };
        }
        else {
            obj = pathOrParams;
            if (obj.path.charAt(0) !== "/") {
                obj.path = "/" + obj.path;
            }
            if (obj.path.substr(0, 18) !== "/services/apexrest") {
                obj.path = "/services/apexrest" + obj.path;
            }
        }
        if (!obj.contentType) {
            obj.contentType = (obj.method == "DELETE" || obj.method == "GET" ? null : "application/json");
        }
        return this.requestData(obj);
    };
    Apex.versions = function () {
        return this.requestData({ path: '/services/data/' });
    };
    Apex.resources = function () {
        return this.requestData({ path: "/services/data/" + this.apiVersion });
    };
    Apex.describeGlobal = function () {
        return this.requestData({ path: "/services/data/" + this.apiVersion + "/sobjects" });
    };
    Apex.metadata = function (objectName) {
        return this.requestData({ path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName });
    };
    Apex.describe = function (objectName) {
        return this.requestData({ path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/describe" });
    };
    Apex.describeLayout = function (objectName, recordTypeId) {
        recordTypeId = recordTypeId || "";
        return this.requestData({
            path: "/services/data/" + this.apiVersion + "/sobjects/" + objectName + "/describe/layouts/" + recordTypeId
        });
    };
    return Apex;
}(base_api_1.BasAPI));
Apex.apiVersion = storage.getWebConfig().apiVersion || constants_1.DEFAULT_API_VERSION;
exports.Apex = Apex;
//# sourceMappingURL=apex.js.map