"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http = require("http");
var storage = require("../storage");
var urls = require("../urls");
var utils = require("../utils");
var parser = require("../parser");
var BasAPI = (function () {
    function BasAPI() {
    }
    BasAPI.refreshToken = function () {
        return new Promise(function (resolve, reject) {
            var tokenData = storage.getTokenData() || '';
            var config = storage.getWebConfig();
            var url = urls.refreshTokenUrl();
            if (tokenData.accessToken === undefined) {
                return reject('Oops! missing access token ');
            }
            if (tokenData.refreshToken === undefined) {
                return reject('Oops! missing refresh token ');
            }
            var params = {
                'grant_type': 'refresh_token',
                'refresh_token': tokenData.refreshToken,
                'client_id': config.clientId
            };
            var finalUrl = url + utils.toQueryString(params);
            var options = {
                url: finalUrl,
                method: 'POST'
            };
            http.request(options).then(function (res) {
                parser.getTokenObject(res.content.toJSON());
                resolve(res);
            })
                .catch(function (error) {
                reject(error);
            });
        });
    };
    BasAPI.requestData = function (value) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var tokenData = storage.getTokenData() || '';
            if (tokenData.accessToken === undefined || tokenData.accessToken === '') {
                return reject('Unauthorized! Please login and again!');
            }
            var finalUrl = tokenData.instanceUrl + value.path + '?' + utils.toQueryString(value.params);
            var headers = {
                "Authorization": "Bearer " + tokenData.accessToken,
                "Cache-Control": 'no-store',
                "Accept": "application/json"
            };
            if (value.contentType !== undefined) {
                headers['Content-Type'] = value.contentType;
            }
            var options = {
                url: finalUrl,
                method: value.method || 'GET',
                headers: headers,
                content: value.data ? JSON.stringify(value.data) : undefined
            };
            http.request(options)
                .then(function (res) {
                if (res.statusCode === 200) {
                    resolve(res);
                }
                else if (res.statusCode === 401) {
                    _this.refreshToken()
                        .then(function (data) {
                        _this.requestData(value).then(function (data) { return resolve(data); }).catch(function (error) { return reject(error); });
                    })
                        .catch(function (error) { reject(error); });
                }
                else {
                    reject(res);
                }
            })
                .catch(function (error) {
                reject(error);
            });
        });
    };
    return BasAPI;
}());
exports.BasAPI = BasAPI;
//# sourceMappingURL=base-api.js.map